@@ -40,8 +40,8 @@ class FormatHelper:
         money_comma = r"\d{1,3}(\.\d\d\d)*(,\d+)?"
         currency = r"([A-Z]{3}|[a-z]{3})"
 
-        day = r"([1-9]|0[1-9]|1[012])"
-        month = r"([1-9]|[012][0-9]|3[01])"
+        day = r"([1-9]|[012][0-9]|3[01])"
+        month = r"([1-9]|0[1-9]|1[012])"
         year = r"(19|20)?\d\d"
         hour24 = r"(0?[0-9]|[01]\d|2[0-3])"
         hour12 = r"(0?[0-9]|1[0-2])"
@@ -97,7 +97,7 @@ class FormatHelper:
             "ipv4 address": r"^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}$",
             # scary - but covers all cases
             "ipv6 address": r"^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))$",
-            "email": r"^[a-zA-ZÀ-ÿĀ-ſƀ-ȳ0-9.\-_%]+@[a-zA-ZÀ-ÿĀ-ſƀ-ȳ0-9.\-_%]+\.[A-Za-z]{2,4}$",
+            "email": r"^[a-zA-ZÀ-ÿĀ-ſƀ-ȳ0-9.\-_%+]+@[a-zA-ZÀ-ÿĀ-ſƀ-ȳ0-9.\-_%]+\.[A-Za-z]{2,4}$",
             "phone number": r"^((\+[0-9]{1,2}\s)?\(?[0-9]{3}\)?[\s.-])?[0-9]{3}[\s.-][0-9]{4}$",
             "credit card number": r"^[0-9]{14}|[0-9]{15}|[0-9]{16}|[0-9]{17}|[0-9]{18}|[0-9]{19}|([0-9]{4}-){3}[0-9]{4}|([0-9]{4} ){3}[0-9]{4}$",
         }
@@ -158,6 +158,7 @@ class DataSource:
         "bigserial",
     ]
     TEXT_TYPES_FOR_PROFILING = ["character varying", "varchar", "text", "character", "char"]
+    LIMIT_KEYWORD = "LIMIT"
 
     # Building up format queries normally works with regexp expression + a set of formats,
     # but some use cases require whole completely custom format expressions.
@@ -175,6 +176,8 @@ class DataSource:
             return "SQLServer"
         elif "mysql" == data_source_type:
             return "MySQL"
+        elif "duckdb" == data_source_type:
+            return "DuckDB"
         else:
             return f"{data_source_type[0:1].upper()}{data_source_type[1:]}"
 
@@ -399,6 +402,7 @@ class DataSource:
         :return: A dict mapping column names to data source data types.  Like eg
         {"id": "varchar", "cst_size": "int8", ...}
         """
+        # TODO: save/cache the result for later use.
         query = Query(
             data_source_scan=self.data_source_scan,
             unqualified_query_name=query_name,
@@ -414,6 +418,9 @@ class DataSource:
     def create_table_columns_query(self, partition: Partition, schema_metric: SchemaMetric) -> TableColumnsQuery:
         return TableColumnsQuery(partition, schema_metric)
 
+    def get_ordinal_position_name(self) -> str:
+        return "ORDINAL_POSITION"
+
     def sql_get_table_columns(
         self,
         table_name: str,
@@ -458,7 +465,7 @@ class DataSource:
             f"SELECT {', '.join(self.column_metadata_columns())} \n"
             f"FROM {self.sql_information_schema_columns()} \n"
             f"WHERE {where_filter}"
-            "\nORDER BY ORDINAL_POSITION"
+            f"\nORDER BY {self.get_ordinal_position_name()}"
         )
         return sql
 
@@ -546,20 +553,50 @@ class DataSource:
     def sql_analyze_table(self, table: str) -> str | None:
         return None
 
-    def sql_get_duplicates(
-        self, column_names: str, table_name: str, filter: str, limit: str | None = None
+    def sql_get_duplicates_count(
+        self,
+        column_names: str,
+        table_name: str,
+        filter: str,
     ) -> str | None:
-        sql = f"""WITH frequencies AS (
+        sql = dedent(
+            f"""
+            WITH frequencies AS (
               SELECT {column_names}, COUNT(*) AS frequency
               FROM {table_name}
               WHERE {filter}
               GROUP BY {column_names})
             SELECT {column_names}, frequency
             FROM frequencies
-            WHERE frequency > 1"""
+            WHERE frequency > 1
+            ORDER BY frequency DESC"""
+        )
+
+        return sql
+
+    def sql_get_duplicates(
+        self,
+        column_names: str,
+        table_name: str,
+        filter: str,
+        limit: str | None = None,
+        invert_condition: bool = False,
+    ) -> str | None:
+        sql = dedent(
+            f"""
+            WITH frequencies AS (
+                SELECT {column_names}, COUNT(*) AS frequency
+                FROM {table_name}
+                WHERE {filter}
+                GROUP BY {column_names})
+            SELECT {column_names}, frequency
+            FROM frequencies
+            WHERE frequency {'<=' if invert_condition else '>'} 1
+            ORDER BY frequency DESC"""
+        )
 
         if limit:
-            sql += f"\n LIMIT {limit}"
+            sql += f"\nLIMIT {limit}"
 
         return sql
 
@@ -1116,13 +1153,21 @@ class DataSource:
             cursor.close()
 
     def sql_select_column_with_filter_and_limit(
-        self, column_name: str, table_name: str, filter_clause: str, limit: int | None = None
+        self,
+        column_name: str,
+        table_name: str,
+        filter_clause: str | None = None,
+        sample_clause: str | None = None,
+        limit: int | None = None,
     ) -> str:
-        limit_str = ""
-        if limit:
-            limit_str = f"\n LIMIT {limit}"
-
-        sql = f"SELECT \n" f"  {column_name} \n" f"FROM {table_name}{filter_clause}{limit_str}"
+        """
+        Returns a SQL query that selects a column from a table with optional filter, sample query
+        and limit.
+        """
+        filter_clauses_str = f"\n WHERE {filter_clause}" if filter_clause else ""
+        sample_clauses_str = f"\n {sample_clause}" if sample_clause else ""
+        limit_str = f"\n LIMIT {limit}" if limit else ""
+        sql = f"SELECT \n" f"  {column_name} \n" f"FROM {table_name}{sample_clauses_str}{filter_clauses_str}{limit_str}"
         return sql
 
     def expr_false_condition(self):
