@@ -7,6 +7,7 @@ import textwrap
 from datetime import datetime, timezone
 
 from soda.__version__ import SODA_CORE_VERSION
+from soda.common.attributes_handler import AttributeHandler
 from soda.common.json_helper import JsonHelper
 from soda.common.log import Log, LogLevel
 from soda.common.logs import Logs
@@ -77,7 +78,6 @@ class Scan:
             profile_table.get_dict()
             for profile_table in self._profile_columns_result_tables + self._sample_tables_result_tables
         ]
-
         return JsonHelper.to_jsonnable(  # type: ignore
             {
                 "definitionName": self._scan_definition_name,
@@ -175,6 +175,9 @@ class Scan:
     def _parse_configuration_yaml_str(self, configuration_yaml_str: str, file_path: str = "yaml string"):
         from soda.configuration.configuration_parser import ConfigurationParser
 
+        # First round of template resolve right when loading a configuration string.
+        configuration_yaml_str = self.jinja_resolve(configuration_yaml_str)
+
         environment_parse = ConfigurationParser(
             configuration=self._configuration,
             logs=self._logs,
@@ -182,6 +185,21 @@ class Scan:
         )
         environment_parse.parse_environment_yaml_str(configuration_yaml_str)
 
+    def add_duckdb_connection(self, duckdb_connection, data_source_name: str = "duckdb"):
+        """
+        Adds a duckdb connection to the scan. Only requireed in case of using a pre-existing
+        duckdb connection object as a data source.
+        """
+        try:
+            self._configuration.add_duckdb_connection(
+                data_source_name=data_source_name, duckdb_connection=duckdb_connection
+            )
+        except Exception as e:
+            self._logs.error(
+                f"Could not add duckdb connection for data_source {data_source_name}",
+                exception=e,
+            )
+
     def add_spark_session(self, spark_session, data_source_name: str = "spark_df"):
         """
         Pass a spark_session to the scan.  Only required in case of PySpark scans.
@@ -357,6 +375,8 @@ class Scan:
                 else:
                     if self._configuration.soda_cloud.is_samples_disabled():
                         self._configuration.sampler = DefaultSampler()
+            else:
+                self._configuration.sampler = DefaultSampler()
 
             # Override the sampler, if it is configured programmatically
             if self.sampler is not None:
@@ -456,6 +476,23 @@ class Scan:
                         f"Metrics '{missing_metrics_str}' were not computed for check '{check.check_cfg.source_line}'"
                     )
 
+                # Validate check attributes as well.
+                if check.check_cfg.source_configurations:
+                    if self._configuration.soda_cloud:
+                        attributes = check.check_cfg.source_configurations.get("attributes", {})
+                        attribute_handler = AttributeHandler(self._logs)
+                        self._logs.info("Validating check attributes.")
+                        # TODO: get attributes schema from Cloud Configuration when it is supported by cloud.
+                        # attributes_schema = self._configuration.soda_cloud.get_check_attributes_schema()
+                        attributes_schema = {}
+
+                        attributes, invalid_attributes = attribute_handler.validate(attributes, attributes_schema)
+
+                        if invalid_attributes:
+                            self._logs.debug(f"Skipping invalid attributes '{invalid_attributes.keys()}'.")
+
+                        check.attributes = attributes
+
             self._logs.info("Scan summary:")
             self.__log_queries(having_exception=False)
             self.__log_queries(having_exception=True)
@@ -743,7 +780,11 @@ class Scan:
 
     def __log_check_group(self, checks, indent, check_outcome, outcome_text):
         for check in checks:
-            self._logs.info(f"{indent}{check.name} [{outcome_text}]")
+            location = ""
+            if verbose:
+                location = f"[{check.check_cfg.location.file_path}] "
+
+            self._logs.info(f"{indent}{check.name} {location}[{outcome_text}]")
             if self._logs.verbose or check_outcome != CheckOutcome.PASS:
                 for diagnostic in check.get_log_diagnostic_lines():
                     self._logs.info(f"{indent}  {diagnostic}")
