@@ -68,7 +68,8 @@ class SodaCloud:
             {
                 "definitionName": scan._scan_definition_name,
                 "defaultDataSource": scan._data_source_name,
-                "dataTimestamp": scan._data_timestamp,  # Can be changed by user, this is shown in Cloud as time of a scan.
+                "dataTimestamp": scan._data_timestamp,
+                # Can be changed by user, this is shown in Cloud as time of a scan.
                 "scanStartTimestamp": scan._scan_start_timestamp,  # Actual time when the scan started.
                 "scanEndTimestamp": scan._scan_end_timestamp,  # Actual time when scan ended.
                 "hasErrors": scan.has_error_logs(),
@@ -96,13 +97,17 @@ class SodaCloud:
         return str(value)
 
     def upload_sample(
-        self, scan: Scan, sample_rows: tuple[tuple], sample_file_name: str, samples_limit: int | None = 100
+        self, scan: Scan, sample_rows: tuple[tuple], sample_file_name: str, samples_limit: int | None
     ) -> str:
         """
         :param sample_file_name: file name without extension
         :return: Soda Cloud file_id
         """
 
+        # Keep the interface of this method backward compatible and allow for samples limit to be None, but do not continue with no limit in such case.
+        if not samples_limit:
+            samples_limit = 100
+
         try:
             scan_definition_name = scan._scan_definition_name
             scan_data_timestamp = scan._data_timestamp
@@ -155,7 +160,9 @@ class SodaCloud:
 
         if "fileId" not in upload_response_json:
             logger.error(f"No fileId received in response: {upload_response_json}")
-        return upload_response_json["fileId"]
+            return None
+        else:
+            return upload_response_json["fileId"]
 
     def send_scan_results(self, scan: Scan):
         scan_results = self.build_scan_results(scan)
@@ -293,9 +300,12 @@ class SodaCloud:
         return self._execute_request("command", command, False, command_name)
 
     def _execute_request(self, request_type: str, request_body: dict, is_retry: bool, request_name: str):
+        from soda.scan import verbose
+
         try:
             request_body["token"] = self._get_token()
-            # logger.debug(f"Sending to Soda Cloud {JsonHelper.to_json_pretty(request_body)}")
+            if verbose:
+                logger.debug(f"Sending to Soda Cloud {JsonHelper.to_json_pretty(request_body)}")
             response = self._http_post(
                 url=f"{self.api_url}/{request_type}", headers=self.headers, json=request_body, request_name=request_name
             )
@@ -308,8 +318,6 @@ class SodaCloud:
                 self.logs.error(
                     f"Error while executing Soda Cloud {request_type} response code: {response.status_code}"
                 )
-                from soda.scan import verbose
-
                 if verbose:
                     self.logs.debug(response.text)
             return response_json
