@@ -25,7 +25,7 @@ class MetricCheckCfg(CheckCfg):
         change_over_time_cfg: ChangeOverTimeCfg | None,
         fail_threshold_cfg: ThresholdCfg | None,
         warn_threshold_cfg: ThresholdCfg | None,
-        samples_limit: int | None = 100,
+        samples_limit: int | None = None,
     ):
         super().__init__(source_header, source_line, source_configurations, location, name, samples_limit)
         self.metric_name: str = metric_name
