@@ -42,6 +42,7 @@ WARN = "warn"
 FAIL = "fail"
 NAME = "name"
 IDENTITY = "identity"
+ATTRIBUTES = "attributes"
 FAIL_CONDITION = "fail condition"
 FAIL_QUERY = "fail query"
 SAMPLES_LIMIT = "samples limit"
@@ -135,7 +136,7 @@ class SodaCLParser(Parser):
                         if antlr_section_header.table_checks_header():
                             self.__parse_table_checks_section(
                                 antlr_section_header.table_checks_header(),
-                                header_str,
+                                self._resolve_jinja(header_str, self.sodacl_cfg.scan._variables),
                                 header_content,
                             )
                         elif antlr_section_header.column_configurations_header():
@@ -528,7 +529,7 @@ class SodaCLParser(Parser):
                         configuration_value,
                         missing_and_valid_cfg,
                     )
-                elif configuration_key not in [NAME, IDENTITY, WARN, FAIL, SAMPLES_LIMIT]:
+                elif configuration_key not in [NAME, IDENTITY, WARN, FAIL, SAMPLES_LIMIT, ATTRIBUTES]:
                     if metric_name != "distribution_difference":
                         self.logs.error(
                             f"Skipping unsupported check configuration: {configuration_key}",
@@ -651,6 +652,7 @@ class SodaCLParser(Parser):
         elif metric_name == "distribution_difference":
             column_name: str = metric_args[0]
             distribution_name: str | None = metric_args[1] if len(metric_args) > 1 else None
+            sample_clause = check_configurations.get("sample")
 
             if check_configurations.get("distribution reference file"):
                 reference_file_path: str = os.path.join(
@@ -679,6 +681,7 @@ class SodaCLParser(Parser):
                 column_name=column_name,
                 distribution_name=distribution_name,
                 filter=filter,
+                sample_clause=sample_clause,
                 method=method,
                 reference_file_path=reference_file_path,
                 fail_threshold_cfg=fail_threshold_cfg,
@@ -1222,7 +1225,7 @@ class SodaCLParser(Parser):
                 set_configuration_value(float(configuration_value))
             except ValueError:
                 self.logs.error(
-                    f"{configuration_type} must be an number (float), but was {configuration_value}",
+                    f"{configuration_type} must be an number (float), but was '{configuration_value}'",
                     location=self.location,
                 )
 
@@ -1456,7 +1459,7 @@ class SodaCLParser(Parser):
             return self.__antlr_parse_identifier(antlr_header.partition_name().identifier())
 
     def __antlr_parse_identifier(self, antlr_identifier) -> str:
-        return antlr_identifier.getText()
+        return self._resolve_jinja(antlr_identifier.getText(), self.sodacl_cfg.scan._variables)
         # TODO consider resolving escape chars from a quoted strings:
         # identifier = re.sub(r'\\(.)', '\g<1>', unquoted_identifier)
 
