@@ -1,4 +1,4 @@
-from typing import Optional
+from __future__ import annotations
 
 from soda.sodacl.check_cfg import CheckCfg
 from soda.sodacl.location import Location
@@ -9,12 +9,12 @@ class UserDefinedFailedRowsExpressionCheckCfg(CheckCfg):
         self,
         source_header: str,
         source_line: str,
-        source_configurations: Optional[dict],
+        source_configurations: dict | None,
         location: Location,
         name: str,
-        fail_condition_sql_expr: Optional[str],
-        samples_limit: Optional[int] = 100,
+        fail_condition_sql_expr: str | None,
+        samples_limit: int | None = None,
     ):
         super().__init__(source_header, source_line, source_configurations, location, name)
         self.samples_limit = samples_limit
-        self.fail_condition_sql_expr: Optional[str] = fail_condition_sql_expr
+        self.fail_condition_sql_expr: str | None = fail_condition_sql_expr
